@@ -80,7 +80,11 @@ get_carriers_polypeptide_go_classifiers_df <- function(rec) {
 #' @export
 parse_drug_carriers_actions <- function(save_table = FALSE) {
   drug_carriers_actions <-
-    map_df(pkg.env$children, ~ get_carriers_actions_df(.x))
+    map_df(pkg.env$children, ~ get_carriers_actions_df(.x)) %>% unique()
+  if (nrow(drug_carriers_actions) > 0) {
+    colnames(drug_carriers_actions) <- c("action", "carrier_id")
+  }
+
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -119,7 +123,7 @@ parse_drug_carriers_actions <- function(save_table = FALSE) {
 #' @export
 parse_drug_carriers_articles <- function(save_table = FALSE) {
   drug_carriers_articles <-
-    map_df(pkg.env$children, ~ get_carriers_articles_df(.x))
+    map_df(pkg.env$children, ~ get_carriers_articles_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -158,7 +162,7 @@ parse_drug_carriers_articles <- function(save_table = FALSE) {
 #' @export
 parse_drug_carriers_textbooks <- function(save_table = FALSE) {
   drug_carriers_textbooks <-
-    map_df(pkg.env$children, ~ get_carriers_textbooks_df(.x))
+    map_df(pkg.env$children, ~ get_carriers_textbooks_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -194,7 +198,8 @@ parse_drug_carriers_textbooks <- function(save_table = FALSE) {
 #' }
 #' @export
 parse_drug_carriers_links <- function(save_table = FALSE) {
-  drug_carriers_links <- map_df(pkg.env$children, ~ get_carriers_links_df(.x))
+  drug_carriers_links <-
+    map_df(pkg.env$children, ~ get_carriers_links_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -234,7 +239,7 @@ parse_drug_carriers_links <- function(save_table = FALSE) {
 #' @export
 parse_drug_carriers_polypeptides <- function(save_table = FALSE) {
   drug_carriers_polypeptides <-
-    map_df(pkg.env$children, ~ get_carriers_polypeptide_df(.x))
+    map_df(pkg.env$children, ~ get_carriers_polypeptide_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -295,7 +300,7 @@ parse_drug_carriers_polypeptides_external_identifiers <-
   function(save_table = FALSE) {
     drug_carriers_polypeptide_external_identifiers <-
       map_df(pkg.env$children,
-             ~ get_carriers_polypeptide_external_identifiers_df(.x))
+             ~ get_carriers_polypeptide_external_identifiers_df(.x)) %>% unique()
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -334,8 +339,11 @@ parse_drug_carriers_polypeptides_external_identifiers <-
 #' @export
 parse_drug_carriers_polypeptides_synonyms <-
   function(save_table = FALSE) {
-    drug_carriers_polypeptide_synonyms <- map_df(pkg.env$children,
-                                                 ~ get_carriers_polypeptide_synonyms_df(.x))
+    drug_carriers_polypeptide_synonyms <-
+      map_df(pkg.env$children,
+             ~ get_carriers_polypeptide_synonyms_df(.x)) %>%
+      unique()
+
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -374,8 +382,11 @@ parse_drug_carriers_polypeptides_synonyms <-
 #' @export
 parse_drug_carriers_polypeptides_pfams <-
   function(save_table = FALSE) {
-    drug_carriers_polypeptide_pfams <- map_df(pkg.env$children,
-                                              ~ get_carriers_polypeptide_pfams_df(.x))
+    drug_carriers_polypeptide_pfams <-
+      map_df(pkg.env$children,
+             ~ get_carriers_polypeptide_pfams_df(.x)) %>%
+      unique()
+
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -415,8 +426,9 @@ parse_drug_carriers_polypeptides_pfams <-
 #' @export
 parse_drug_carriers_polypeptides_go_classifiers <-
   function(save_table = FALSE) {
-    drug_carriers_polypeptides_go_classifiers <- map_df(pkg.env$children,
-                                                        ~ get_carriers_polypeptide_go_classifiers_df(.x))
+    drug_carriers_polypeptides_go_classifiers <-
+      map_df(pkg.env$children,
+             ~ get_carriers_polypeptide_go_classifiers_df(.x)) %>% unique()
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -452,7 +464,7 @@ parse_drug_carriers_polypeptides_go_classifiers <-
 #' }
 #' @export
 parse_drug_carriers <- function(save_table = FALSE) {
-  drug_carriers <- map_df(pkg.env$children, ~ get_carriers_df(.x))
+  drug_carriers <- map_df(pkg.env$children, ~ get_carriers_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
