@@ -83,7 +83,8 @@ parse_drug_targets_polypeptides_external_identifiers <-
   function(save_table = FALSE) {
     drug_targets_polypeptide_external_identifiers <-
       map_df(pkg.env$children,
-             ~ get_targets_polypeptide_external_identifiers_df(.x))
+             ~ get_targets_polypeptide_external_identifiers_df(.x)) %>%
+      unique()
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -92,7 +93,7 @@ parse_drug_targets_polypeptides_external_identifiers <-
         save_table_only = TRUE
       )
     }
-    return(drug_targets_polypeptide_external_identifiers)
+    return(tibble::as_tibble(drug_targets_polypeptide_external_identifiers))
   }
 
 
@@ -123,8 +124,10 @@ parse_drug_targets_polypeptides_external_identifiers <-
 #' @export
 parse_drug_targets_polypeptides_synonyms <-
   function(save_table = FALSE) {
-    drug_targets_polypeptide_synonyms <- map_df(pkg.env$children,
-                                                ~ get_targets_polypeptide_synonyms_df(.x))
+    drug_targets_polypeptide_synonyms <-
+      map_df(pkg.env$children,
+             ~ get_targets_polypeptide_synonyms_df(.x)) %>%
+      unique()
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -164,8 +167,11 @@ parse_drug_targets_polypeptides_synonyms <-
 #' @export
 parse_drug_targets_polypeptides_pfams <-
   function(save_table = FALSE) {
-    drug_targets_polypeptide_pfams <- map_df(pkg.env$children,
-                                             ~ get_targets_polypeptide_pfams_df(.x))
+    drug_targets_polypeptide_pfams <-
+      map_df(pkg.env$children,
+             ~ get_targets_polypeptide_pfams_df(.x)) %>%
+      unique()
+
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -174,7 +180,7 @@ parse_drug_targets_polypeptides_pfams <-
         save_table_only = TRUE
       )
     }
-    return(drug_targets_polypeptide_pfams)
+    return(tibble::as_tibble(drug_targets_polypeptide_pfams))
   }
 
 
@@ -206,8 +212,11 @@ parse_drug_targets_polypeptides_pfams <-
 #' @export
 parse_drug_targets_polypeptides_go_classifiers <-
   function(save_table = FALSE) {
-    drug_targets_polypeptides_go_classifiers <- map_df(pkg.env$children,
-                                                       ~ get_targets_polypeptide_go_classifiers_df(.x))
+    drug_targets_polypeptides_go_classifiers <-
+      map_df(pkg.env$children,
+             ~ get_targets_polypeptide_go_classifiers_df(.x)) %>%
+      unique()
+
     if (save_table) {
       save_drug_sub(
         con = pkg.env$con,
@@ -216,7 +225,7 @@ parse_drug_targets_polypeptides_go_classifiers <-
         save_table_only = TRUE
       )
     }
-    return(drug_targets_polypeptides_go_classifiers)
+    return(tibble::as_tibble(drug_targets_polypeptides_go_classifiers))
   }
 
 #' Extracts the drug targets actions element and return data as data frame.
@@ -245,7 +254,13 @@ parse_drug_targets_polypeptides_go_classifiers <-
 #' @export
 parse_drug_targets_actions <- function(save_table = FALSE) {
   drug_targets_actions <-
-    map_df(pkg.env$children, ~ get_targets_actions_df(.x))
+    map_df(pkg.env$children, ~ get_targets_actions_df(.x)) %>%
+    unique()
+
+  if (nrow(drug_targets_actions) > 0) {
+    colnames(drug_targets_actions) <- c("action", "target_id")
+  }
+
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -254,7 +269,7 @@ parse_drug_targets_actions <- function(save_table = FALSE) {
       save_table_only = TRUE
     )
   }
-  return(drug_targets_actions)
+  return(tibble::as_tibble(drug_targets_actions))
 }
 
 #' Extracts the drug targets articles element and return data as data frame.
@@ -283,7 +298,7 @@ parse_drug_targets_actions <- function(save_table = FALSE) {
 #' @export
 parse_drug_targets_articles <- function(save_table = FALSE) {
   drug_targets_articles <-
-    map_df(pkg.env$children, ~ get_targets_articles_df(.x))
+    map_df(pkg.env$children, ~ get_targets_articles_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -292,7 +307,7 @@ parse_drug_targets_articles <- function(save_table = FALSE) {
       save_table_only = TRUE
     )
   }
-  return(drug_targets_articles)
+  return(tibble::as_tibble(drug_targets_articles))
 }
 
 #' Extracts the drug targets textbooks element and return data as data frame.
@@ -321,7 +336,7 @@ parse_drug_targets_articles <- function(save_table = FALSE) {
 #' @export
 parse_drug_targets_textbooks <- function(save_table = FALSE) {
   drug_targets_textbooks <-
-    map_df(pkg.env$children, ~ get_targets_textbooks_df(.x))
+    map_df(pkg.env$children, ~ get_targets_textbooks_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -330,7 +345,7 @@ parse_drug_targets_textbooks <- function(save_table = FALSE) {
       save_table_only = TRUE
     )
   }
-  return(drug_targets_textbooks)
+  return(tibble::as_tibble(drug_targets_textbooks))
 }
 
 #' Extracts the drug targets links element and return data as data frame.
@@ -357,7 +372,7 @@ parse_drug_targets_textbooks <- function(save_table = FALSE) {
 #' }
 #' @export
 parse_drug_targets_links <- function(save_table = FALSE) {
-  drug_targets_links <- map_df(pkg.env$children, ~ get_targets_links_df(.x))
+  drug_targets_links <- map_df(pkg.env$children, ~ get_targets_links_df(.x)) %>% unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -375,7 +390,7 @@ parse_drug_targets_links <- function(save_table = FALSE) {
       )
     )
   }
-  return(drug_targets_links)
+  return(tibble::as_tibble(drug_targets_links))
 }
 
 #' Extracts the drug targets polypeptides element and return data as data frame.
@@ -405,7 +420,8 @@ parse_drug_targets_links <- function(save_table = FALSE) {
 #' @export
 parse_drug_targets_polypeptides <- function(save_table = FALSE) {
   drug_targets_polypeptides <-
-    map_df(pkg.env$children, ~ get_targets_polypeptide_df(.x))
+    map_df(pkg.env$children, ~ get_targets_polypeptide_df(.x)) %>%
+    unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
@@ -452,7 +468,9 @@ parse_drug_targets_polypeptides <- function(save_table = FALSE) {
 #' }
 #' @export
 parse_drug_targets <- function(save_table = FALSE) {
-  drug_targets <- map_df(pkg.env$children, ~ get_targets_df(.x))
+  drug_targets <-
+    map_df(pkg.env$children, ~ get_targets_df(.x)) %>%
+    unique()
   if (save_table) {
     save_drug_sub(
       con = pkg.env$con,
